@@ -1,6 +1,6 @@
 use utf8;
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151530';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151552';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
@@ -86,8 +86,16 @@ sub parse_attributs{
 	my @implicit_args = @{shift()};
 	my %attrs;
 	IMPLICIT_ARGUMENT:
-	while(@_ and ref($_[0]) =~ /^(?:|SCALAR)$/){
-		$attrs{ shift @implicit_args } = shift @_;
+	while(@_ and @implicit_args){
+		my $ref = ref($_[0]);
+		my $implicit = shift @implicit_args || '';
+		last unless $ref =~ /^(?:|SCALAR)$/
+		or (substr($implicit,0,1) eq '@' and $ref eq 'ARRAY')
+		or (substr($implicit,0,1) eq '%' and $ref eq 'HASH')
+		or (substr($implicit,0,1) eq '\\' and $ref eq 'REF')
+		or (substr($implicit,0,1) eq '*');
+		$implicit =~ s/^[\\\*\%\@]//;
+		$attrs{ $implicit } = shift @_;
 	}
 	if(my $args = shift){
 		if(ref($args) eq 'HASH'){
@@ -100,6 +108,21 @@ sub parse_attributs{
 	return \%attrs;
 }	
 
+sub dxmenu {
+    my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id @items onItemClick)], @_ );
+	my $id = delete($attrs->{id}) // new_id( $c, $attrs );	
+	dxbind( $c, 'dxMenu' => $id => $attrs);
+}
+
+
+sub dxloadpanel {
+    my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id message)], @_ );
+	my $id = delete($attrs->{id}) // new_id( $c, $attrs );	
+	dxbind( $c, 'dxLoadPanel' => $id => $attrs);
+}
+
 
 sub dxbutton {
     my $c = shift;
@@ -248,6 +271,7 @@ my @without_prefix = qw( dxbuild required_assets require_asset );
 
 #Helper method to export with prepending a prefix
 my @with_prefix = qw( Button DataGrid Popup TextBox TextArea Switch
+	Menu LoadPanel
 	SelectBox NumberBox List DateBox CheckBox Calendar Box Lookup );
 sub register {
 	my ( $self, $app, $args ) = @_;
@@ -294,7 +318,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.151530
+version 0.151552
 
 =head1 SUBROUTINES/METHODS
 
@@ -344,6 +368,14 @@ Internal usage
 
 	my $attrs = parse_attributs( $c, \@implicit_arguments, @attributs )
 
+=head2 dxmenu C< $id, \@items ,[ \%options ]>
+
+	%= dxmenu mainMenu => [{ id => 1, text => 'Back', iconSrc => '/images/back.png', link => 'javascript:location.back();' }], \q% function(e){return e.itemData.link;} %
+
+=head2 dxloadpanel C<[ $id, [ $message ] ], [ \%options ]>
+
+	%= dxloadpanel myLoadPanel => 'Please wait'
+
 =head2 dxbutton C<[ $id, [ $text, [ $onclick ] ] ], [ \%options ]>
 
 	%= dxbutton myButtonId => 'My button' => q{ function (){ alert('onClick!'); } }
